##
##  webdav.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2025 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_opkg  5.7.4
%define       V_dist  20250319

#   package information
Name:         webdav
Summary:      WebDAV Server
URL:          https://github.com/hacdias/webdav
Vendor:       Henrique Dias
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Networking
License:      MIT
Version:      %{V_opkg}.%{V_dist}
Release:      20250319

#   list of sources
Source0:      http://download.openpkg.org/components/versioned/webdav/webdav-%{V_dist}.tar.xz
Source1:      webdav.yaml
Source2:      rc.webdav

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, go
PreReq:       OpenPKG, openpkg >= 20160101

%description
    WebDAV is a simple WebDAV-compliant server.

%track
    prog webdav:release = {
        version   = %{V_opkg}
        url       = https://github.com/hacdias/webdav/releases
        regex     = tree/v(__VER__)
    }
    prog webdav:snapshot = {
        version   = %{V_dist}
        url       = http://download.openpkg.org/components/versioned/webdav/
        regex     = webdav-(__VER__)\.tar\.xz
    }

%prep
    %setup -q -n webdav

%build
    #   build program
    export GOPATH=`pwd`
    cd src/github.com/hacdias/webdav
    go build -v -o webdav

%install
    #   install program
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/sbin
    %{l_shtool} install -c -s -m 755 \
        src/github.com/hacdias/webdav/webdav \
        $RPM_BUILD_ROOT%{l_prefix}/sbin/

    #   install default configuration
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/etc/webdav
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE webdav.yaml} $RPM_BUILD_ROOT%{l_prefix}/etc/webdav/

    #   install run-command script
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        %{SOURCE rc.webdav} $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d/

    #   create run-time directories
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/var/webdav/run \
        $RPM_BUILD_ROOT%{l_prefix}/var/webdav/log \
        $RPM_BUILD_ROOT%{l_prefix}/var/webdav/data

    #   provide sample data
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/var/webdav/data/example
    echo "Example" \
        >$RPM_BUILD_ROOT%{l_prefix}/var/webdav/data/example/example.txt

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/webdav/*' \
        '%attr(-,%{l_rusr},%{l_rgrp}) %{l_prefix}/var/webdav/*' \
        '%attr(-,%{l_rusr},%{l_rgrp}) %{l_prefix}/var/webdav/*/*' \
        '%attr(-,%{l_rusr},%{l_rgrp}) %{l_prefix}/var/webdav/*/*/*'

%files -f files

%clean

%post
    if [ $1 -eq 2 ]; then
        #   after upgrade, restart service
        eval `%{l_rc} webdav status 2>/dev/null`
        [ ".$webdav_active" = .yes ] && %{l_rc} webdav restart
    fi
    exit 0

%preun
    if [ $1 -eq 0 ]; then
        #   before erase, stop service and remove log files
        %{l_rc} webdav stop 2>/dev/null
        rm -rf $RPM_INSTALL_PREFIX/var/webdav/log/*  >/dev/null 2>&1 || true
        rm -rf $RPM_INSTALL_PREFIX/var/webdav/run/*  >/dev/null 2>&1 || true
        rm -rf $RPM_INSTALL_PREFIX/var/webdav/data/* >/dev/null 2>&1 || true
    fi
    exit 0

